@@ -25,10 +25,10 @@
 #include "eckit/utils/Regex.h"
 #include "eckit/memory/NonCopyable.h"
 
-#include "fdb5/database/Catalogue.h"
+#include "fdb5/database/DB.h"
 #include "fdb5/config/Config.h"
 #include "fdb5/api/FDBStats.h"
-#include "fdb5/api/helpers/ListIterator.h"
+#include "fdb5/api/helpers/AxesIterator.h"
 #include "fdb5/api/helpers/ListIterator.h"
 #include "fdb5/api/helpers/ControlIterator.h"
 #include "fdb5/api/helpers/DumpIterator.h"
@@ -38,17 +38,13 @@
 #include "fdb5/api/helpers/StatsIterator.h"
 #include "fdb5/api/helpers/StatusIterator.h"
 
-namespace eckit::message {
-
+namespace eckit {
+namespace message {
 class Message;
+}
+}  // namespace eckit
 
-}  // namespace eckit::message
-
-namespace metkit {
-
-class MarsRequest;
-
-} // namespace metkit
+namespace metkit { class MarsRequest; }
 
 namespace fdb5 {
 
@@ -92,6 +88,8 @@ public: // methods
 
     virtual MoveIterator move(const FDBToolRequest& request, const eckit::URI& dest) = 0;
 
+    virtual AxesIterator axes(const FDBToolRequest& request, int axes) { NOTIMP; }
+
     // -------------- API management ----------------------------
 
     /// ID used for hashing in the Rendezvous hash. Should be unique amongst those used
