@@ -17,7 +17,7 @@
 #include "fdb5/api/local/MoveVisitor.h"
 
 #include "fdb5/api/local/QueueStringLogTarget.h"
-#include "fdb5/database/Catalogue.h"
+#include "fdb5/database/DB.h"
 #include "fdb5/database/Index.h"
 #include "fdb5/LibFdb5.h"
 
@@ -41,8 +41,7 @@ MoveVisitor::MoveVisitor(eckit::Queue<MoveElement>& queue,
     QueryVisitor<MoveElement>(queue, request),
     dest_(dest) {}
 
-//bool MoveVisitor::visitDatabase(const Catalogue& catalogue, const Store& store) {
-bool MoveVisitor::visitDatabase(const Catalogue& catalogue) {
+bool MoveVisitor::visitDatabase(const Catalogue& catalogue, const Store& store) {
     if (catalogue.key().match(request_)) {
         catalogue.control(
             ControlAction::Disable,
@@ -53,14 +52,11 @@ bool MoveVisitor::visitDatabase(const Catalogue& catalogue) {
         ASSERT(!catalogue.enabled(ControlIdentifier::Wipe));
         ASSERT(!catalogue.enabled(ControlIdentifier::UniqueRoot));
 
-        EntryVisitor::visitDatabase(catalogue);
-//        EntryVisitor::visitDatabase(catalogue, store);
+        EntryVisitor::visitDatabase(catalogue, store);
 
         ASSERT(!internalVisitor_);
-        // internalVisitor_.reset(catalogue.moveVisitor(store, request_, dest_, queue_));
-        // internalVisitor_->visitDatabase(catalogue, store);
-        internalVisitor_.reset(catalogue.moveVisitor(store(), request_, dest_, queue_));
-        internalVisitor_->visitDatabase(catalogue);
+        internalVisitor_.reset(catalogue.moveVisitor(store, request_, dest_, queue_));
+        internalVisitor_->visitDatabase(catalogue, store);
 
         return true;
     }
