@@ -18,27 +18,22 @@
 #include "fdb5/database/BaseArchiveVisitor.h"
 #include "fdb5/rules/Schema.h"
 #include "fdb5/rules/Rule.h"
-#include "fdb5/database/Store.h"
 
 namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
+
 Archiver::Archiver(const Config& dbConfig) :
     dbConfig_(dbConfig),
-    catalogue_(nullptr),
-    store_(nullptr) {}
+    current_(nullptr) {
+}
 
 Archiver::~Archiver() {
+
     flush(); // certify that all sessions are flushed before closing them
 
-    // for (auto it = databases_.begin(); it != databases_.end(); it++) {
-    //     databases_.erase(it);
-    // }
-
-//    std::cout << databases_.size();
-
-    // databases_.clear(); //< explicitly delete the DBs before schemas are destroyed
+    databases_.clear(); //< explicitly delete the DBs before schemas are destroyed
 }
 
 void Archiver::archive(const Key &key, const void* data, size_t len) {
@@ -50,6 +45,7 @@ void Archiver::archive(const Key &key, BaseArchiveVisitor& visitor) {
 
     visitor.rule(nullptr);
     
+
     dbConfig_.schema().expand(key, visitor);
 
     const Rule* rule = visitor.rule();
@@ -63,21 +59,20 @@ void Archiver::archive(const Key &key, BaseArchiveVisitor& visitor) {
 }
 
 void Archiver::flush() {
-    for (auto i = databases_.begin(); i != databases_.end(); ++i) {
-        i->second.store_->flush();      // flush the store
-        i->second.catalogue_->flush();  // flush the catalogue
+    for (store_t::iterator i = databases_.begin(); i != databases_.end(); ++i) {
+        i->second.second->flush();
     }
 }
 
-void Archiver::selectDatabase(const Key &dbKey) {
 
-    auto i = databases_.find(dbKey);
+DB& Archiver::database(const Key &key) {
+
+    store_t::iterator i = databases_.find(key);
 
     if (i != databases_.end() ) {
-        catalogue_ = i->second.catalogue_.get();
-        store_ = i->second.store_.get();
-        i->second.time_ = ::time(0);
-        return;
+        DB& db = *(i->second.second);
+        i->second.first = ::time(0);
+        return db;
     }
 
     static size_t fdbMaxNbDBsOpen = eckit::Resource<size_t>("fdbMaxNbDBsOpen", 64);
@@ -86,37 +81,33 @@ void Archiver::selectDatabase(const Key &dbKey) {
         bool found = false;
         time_t oldest = ::time(0) + 24 * 60 * 60;
         Key oldK;
-        for (auto i = databases_.begin(); i != databases_.end(); ++i) {
-            if (i->second.time_ <= oldest) {
+        for (store_t::iterator i = databases_.begin(); i != databases_.end(); ++i) {
+            if (i->second.first <= oldest) {
                 found = true;
                 oldK = i->first;
-                oldest = i->second.time_;
+                oldest = i->second.first;
             }
         }
         if (found) {
-            databases_[oldK].store_->flush();
-            databases_[oldK].catalogue_->flush();
-            
-            eckit::Log::info() << "Closing database " << *databases_[oldK].catalogue_ << std::endl;
+            eckit::Log::info() << "Closing database " << *databases_[oldK].second << std::endl;
             databases_.erase(oldK);
         }
     }
 
-    std::unique_ptr<CatalogueWriter> cat = CatalogueWriterFactory::instance().build(dbKey, dbConfig_);
-    ASSERT(cat);
+    std::unique_ptr<DB> db = DB::buildWriter(key, dbConfig_);
+
+    ASSERT(db);
 
     // If this database is locked for writing then this is an error
-    if (!cat->enabled(ControlIdentifier::Archive)) {
+    if (!db->enabled(ControlIdentifier::Archive)) {
         std::ostringstream ss;
-        ss << "Database " << *cat << " matched for archived is LOCKED against archiving";
+        ss << "Database " << *db << " matched for archived is LOCKED against archiving";
         throw eckit::UserError(ss.str(), Here());
     }
 
-    std::unique_ptr<Store> str = cat->buildStore();
-    catalogue_ = cat.get();
-    store_ = str.get();
-
-    databases_[dbKey] = Database{::time(0), std::move(cat), std::move(str)};
+    DB& out = *db;
+    databases_[key] = std::make_pair(::time(0), std::move(db));
+    return out;
 }
 
 void Archiver::print(std::ostream &out) const {
