@@ -79,7 +79,6 @@ void IndexBase::decodeLegacy(eckit::Stream& s, const int version) { // decoding
 
     axes_.decode(s, version);
 
-
     std::string dummy;
     s >> key_;
     s >> dummy; ///< legacy entry, no longer used but stays here so we can read existing indexes
@@ -122,13 +121,13 @@ void IndexBase::encodeLegacy(eckit::Stream& s, const int version) const {
 
     axes_.encode(s, version);
     s << key_;
-    s << ""; // key_.valuesToString();    we no longer write this field, required in the previous index format
+    s << key_.valuesToString(); // we no longer write this field, required in the previous index format
     s << type_;
 }
 
-void IndexBase::put(const InspectionKey &key, const Field &field) {
+void IndexBase::put(const Key &key, const Field &field) {
 
-    eckit::Log::debug<LibFdb5>() << "FDB Index " << indexer_ << " " << key << " -> " << field << std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "FDB Index " << indexer_ << " " << key << " -> " << field << std::endl;
 
     axes_.insert(key);
     add(key, field);
@@ -143,7 +142,7 @@ bool IndexBase::partialMatch(const metkit::mars::MarsRequest& request) const {
     return true;
 }
 
-bool IndexBase::mayContain(const InspectionKey &key) const {
+bool IndexBase::mayContain(const Key &key) const {
     return axes_.contains(key);
 }
 
@@ -202,8 +201,8 @@ private: // methods
 
     virtual void visit(IndexLocationVisitor&) const override { NOTIMP; }
 
-    virtual bool get( const InspectionKey&, const Key&, Field&) const override { NOTIMP; }
-    virtual void add( const InspectionKey&, const Field&) override { NOTIMP; }
+    virtual bool get( const Key&, const Key&, Field&) const override { NOTIMP; }
+    virtual void add( const Key&, const Field&) override { NOTIMP; }
     virtual void flush() override { NOTIMP; }
     virtual void encode(eckit::Stream&, const int version) const override { NOTIMP; }
     virtual void entries(EntryVisitor&) const override { NOTIMP; }
