@@ -16,7 +16,7 @@
 
 #include "fdb5/database/AxisRegistry.h"
 #include "fdb5/database/IndexAxis.h"
-#include "fdb5/database/InspectionKey.h"
+#include "fdb5/database/Key.h"
 #include "fdb5/types/TypesRegistry.h"
 #include "fdb5/types/Type.h"
 
@@ -45,6 +45,35 @@ IndexAxis::IndexAxis(eckit::Stream &s, const int version) :
     decode(s, version);
 }
 
+IndexAxis::IndexAxis(IndexAxis&& rhs) noexcept :
+        axis_(std::move(rhs.axis_)),
+        readOnly_(rhs.readOnly_),
+        dirty_(rhs.dirty_) {}
+
+IndexAxis& IndexAxis::operator=(IndexAxis&& rhs) noexcept {
+    axis_ = std::move(rhs.axis_);
+    readOnly_ = rhs.readOnly_;
+    dirty_ = rhs.dirty_;
+    return *this;
+}
+
+bool IndexAxis::operator==(const IndexAxis& rhs) const {
+
+    if (axis_.size() != rhs.axis_.size()) return false;
+
+    for (const auto& kv : axis_) {
+        auto it = rhs.axis_.find(kv.first);
+        if (it == rhs.axis_.end()) return false;
+        if (*kv.second != *it->second) return false;
+    }
+
+    return true;
+}
+
+bool IndexAxis::operator!=(const IndexAxis& rhs) const {
+    return !(*this == rhs);
+}
+
 void IndexAxis::encode(eckit::Stream &s, const int version) const {
     if (version >= 3) {
         encodeCurrent(s, version);
@@ -130,7 +159,7 @@ void IndexAxis::decodeCurrent(eckit::Stream &s, const int version) {
                 ASSERT(n);
                 for (size_t i = 0; i < n; i++) {
                     s >> k;
-                    std::shared_ptr<eckit::DenseSet<std::string>>& values = axis_[k];
+                    std::shared_ptr<eckit::DenseSet<std::string> >& values = axis_[k];
                     values.reset(new eckit::DenseSet<std::string>);
                     size_t m;
                     s >> m;
@@ -150,7 +179,6 @@ void IndexAxis::decodeCurrent(eckit::Stream &s, const int version) {
 }
 
 void IndexAxis::decodeLegacy(eckit::Stream& s, const int version) {
-
     ASSERT(version <= 2);
 
     size_t n;
@@ -161,7 +189,7 @@ void IndexAxis::decodeLegacy(eckit::Stream& s, const int version) {
 
     for (size_t i = 0; i < n; i++) {
         s >> k;
-        std::shared_ptr<eckit::DenseSet<std::string>>& values = axis_[k];
+        std::shared_ptr<eckit::DenseSet<std::string> >& values = axis_[k];
         values.reset(new eckit::DenseSet<std::string>);
         size_t m;
         s >> m;
@@ -221,7 +249,7 @@ bool IndexAxis::partialMatch(const metkit::mars::MarsRequest& request) const {
     return true;
 }
 
-bool IndexAxis::contains(const InspectionKey &key) const {
+bool IndexAxis::contains(const Key &key) const {
 
     for (AxisMap::const_iterator i = axis_.begin(); i != axis_.end(); ++i) {
         if (!key.match(i->first, *(i->second))) {
@@ -231,13 +259,13 @@ bool IndexAxis::contains(const InspectionKey &key) const {
     return true;
 }
 
-void IndexAxis::insert(const InspectionKey &key) {
+void IndexAxis::insert(const Key &key) {
     ASSERT(!readOnly_);
 
     for (Key::const_iterator i = key.begin(); i  != key.end(); ++i) {
         const std::string &keyword = i->first;
 
-        std::shared_ptr<eckit::DenseSet<std::string>>& axis_set = axis_[keyword];
+        std::shared_ptr<eckit::DenseSet<std::string> >& axis_set = axis_[keyword];
         if (!axis_set)
             axis_set.reset(new eckit::DenseSet<std::string>);
 
@@ -293,13 +321,59 @@ const eckit::DenseSet<std::string> &IndexAxis::values(const std::string &keyword
     return *(i->second);
 }
 
+std::map<std::string, eckit::DenseSet<std::string>> IndexAxis::map() const {
+
+    // Make a copy of the axis map
+    std::map<std::string, eckit::DenseSet<std::string>> result;
+
+    for (const auto& kv : axis_) {
+        result.emplace(kv.first, *kv.second);
+    }
+    return result;
+}
+
 void IndexAxis::print(std::ostream &out) const {
     out << "IndexAxis["
         <<  "axis=";
-    eckit::__print_container(out, axis_);
+
+    const char* sep = "";
+    out << "{";
+    for (const auto& kv : axis_) {
+        out << sep << kv.first << "=(";
+        const char* sep2 = "";
+        for (const auto& v : *kv.second) {
+            out << sep2 << v;
+            sep2 = ",";
+        }
+        out << ")";
+        sep = ",";
+    }
+    out << "}";
     out  << "]";
 }
 
+void IndexAxis::json(eckit::JSON& json) const {
+    json.startObject();
+    for (const auto& kv : axis_) {
+        json << kv.first << *kv.second;
+    }
+    json.endObject();
+}
+
+void IndexAxis::merge(const fdb5::IndexAxis& other) {
+
+    ASSERT(!readOnly_);
+    for (const auto& kv : other.axis_) {
+
+        auto it = axis_.find(kv.first);
+        if (it == axis_.end()) {
+            axis_.emplace(kv.first, kv.second);
+        } else {
+            it->second->merge(*kv.second);
+        };
+    }
+}
+
 //----------------------------------------------------------------------------------------------------------------------
 
 } // namespace fdb5
