@@ -12,7 +12,8 @@
 /// @author Emanuele Danovaro
 /// @date   August 2019
 
-#pragma once
+#ifndef fdb5_Store_H
+#define fdb5_Store_H
 
 #include "eckit/distributed/Transport.h"
 #include "eckit/filesystem/URI.h"
@@ -20,7 +21,7 @@
 
 #include "fdb5/api/helpers/MoveIterator.h"
 #include "fdb5/config/Config.h"
-#include "fdb5/database/Catalogue.h"
+#include "fdb5/database/DB.h"
 #include "fdb5/database/Field.h"
 #include "fdb5/database/FieldLocation.h"
 #include "fdb5/database/Key.h"
@@ -30,14 +31,12 @@ namespace fdb5 {
 class Store {
 public:
 
-    Store() {}
+    Store(const Schema& schema) : schema_(schema) {}
 
     virtual ~Store() {}
 
     virtual eckit::DataHandle* retrieve(Field& field) const = 0;
-//    virtual void archive(const Key& key, const void *data, eckit::Length length, void(*catalogue_archive)(std::unique_ptr<FieldLocation> fieldLocation)) = 0;
-    virtual void archive(const Key& key, const void *data, eckit::Length length, std::function<void(const std::unique_ptr<FieldLocation> fieldLocation)> catalogue_archive);
-    virtual std::unique_ptr<FieldLocation> archive(const Key& key, const void *data, eckit::Length length);
+    virtual std::unique_ptr<FieldLocation> archive(const Key &key, const void *data, eckit::Length length) = 0;
 
     virtual void remove(const eckit::URI& uri, std::ostream& logAlways, std::ostream& logVerbose, bool doit = true) const = 0;
 
@@ -58,7 +57,9 @@ public:
     virtual void remove(const Key& key) const { NOTIMP; }
 
     virtual eckit::URI uri() const = 0;
-    
+
+protected: // members
+    const Schema& schema_;  //<< schema is owned by catalogue which always outlives the store
 };
 
 
@@ -70,14 +71,14 @@ class StoreBuilderBase {
 public:
     StoreBuilderBase(const std::string&);
     virtual ~StoreBuilderBase();
-    virtual std::unique_ptr<Store> make(const Key& key, const Config& config) = 0;
-    virtual std::unique_ptr<Store> make(const eckit::URI& uri, const Config& config) = 0;
+    virtual std::unique_ptr<Store> make(const Schema& schema, const Key& key, const Config& config) = 0;
+    virtual std::unique_ptr<Store> make(const Schema& schema, const eckit::URI& uri, const Config& config) = 0;
 };
 
 template <class T>
 class StoreBuilder : public StoreBuilderBase {
-    virtual std::unique_ptr<Store> make(const Key& key, const Config& config) override { return std::unique_ptr<T>(new T(key, config)); }
-    virtual std::unique_ptr<Store> make(const eckit::URI& uri, const Config& config) override { return std::unique_ptr<T>(new T(uri, config)); }
+    virtual std::unique_ptr<Store> make(const Schema& schema, const Key& key, const Config& config) override { return std::unique_ptr<T>(new T(schema, key, config)); }
+    virtual std::unique_ptr<Store> make(const Schema& schema, const eckit::URI& uri, const Config& config) override { return std::unique_ptr<T>(new T(schema, uri, config)); }
 
 public:
     StoreBuilder(const std::string& name) : StoreBuilderBase(name) {}
@@ -94,15 +95,17 @@ public:
     bool has(const std::string& name);
     void list(std::ostream&);
 
+    /// @param schema    the schema read by the catalog
     /// @param key       the user-specified key
     /// @param config    the fdb config
     /// @returns         store built by specified builder
-    std::unique_ptr<Store> build(const Key& key, const Config& config);
+    std::unique_ptr<Store> build(const Schema& schema, const Key& key, const Config& config);
 
+    /// @param schema    the schema read by the catalog
     /// @param uri       search uri
     /// @param config    the fdb config
     /// @returns         store built by specified builder
-    std::unique_ptr<Store> build(const eckit::URI& uri, const Config& config);
+    std::unique_ptr<Store> build(const Schema& schema, const eckit::URI& uri, const Config& config);
 
 private:
     StoreFactory();
@@ -112,3 +115,4 @@ private:
 };
 
 }
+#endif  // fdb5_Store_H
