@@ -14,13 +14,10 @@
  */
 
 #include "fdb5/remote/RemoteFieldLocation.h"
-#include "fdb5/remote/RemoteStore.h"
-#include "fdb5/remote/client/ClientConnectionRouter.h"
-#include "fdb5/LibFdb5.h"
+#include "fdb5/api/RemoteFDB.h"
 
 #include "eckit/exception/Exceptions.h"
 #include "eckit/filesystem/URIManager.h"
-#include "eckit/log/Log.h"
 
 namespace fdb5 {
 namespace remote {
@@ -30,46 +27,30 @@ namespace remote {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-RemoteFieldLocation::RemoteFieldLocation(const eckit::net::Endpoint& endpoint, const FieldLocation& remoteLocation) :
-    FieldLocation(
-        eckit::URI("fdb", remoteLocation.uri(), endpoint.hostname(),  endpoint.port()),
-        remoteLocation.offset(),
-        remoteLocation.length(),
-        remoteLocation.remapKey()) {
-
+RemoteFieldLocation::RemoteFieldLocation(RemoteFDB* remoteFDB, const FieldLocation& remoteLocation) :
+    FieldLocation(eckit::URI("fdb", remoteFDB->controlEndpoint().host(),  remoteFDB->controlEndpoint().port())),
+    remoteFDB_(remoteFDB),
+    internal_(remoteLocation.make_shared()) {
+    ASSERT(remoteFDB);
     ASSERT(remoteLocation.uri().scheme() != "fdb");
-    if (!remoteLocation.uri().scheme().empty()) {
-        uri_.query("internalScheme", remoteLocation.uri().scheme());
-    }
-    if (!remoteLocation.host().empty()) {
-        uri_.query("internalHost", remoteLocation.host());
-    }
 }
 
-RemoteFieldLocation::RemoteFieldLocation(const eckit::net::Endpoint& endpoint, const RemoteFieldLocation& remoteLocation) :
-    FieldLocation(
-        eckit::URI("fdb", remoteLocation.uri(), endpoint.hostname(),  endpoint.port()),
-        remoteLocation.offset(),
-        remoteLocation.length(),
-        remoteLocation.remapKey()) {}
-
 RemoteFieldLocation::RemoteFieldLocation(const eckit::URI& uri) :
-    FieldLocation(eckit::URI("fdb", uri)) {
-    NOTIMP;
-}
+    FieldLocation(eckit::URI("fdb://" + uri.hostport())),
+    internal_(std::shared_ptr<FieldLocation>(FieldLocationFactory::instance().build(uri.scheme(), uri))) {}
 
 RemoteFieldLocation::RemoteFieldLocation(const eckit::URI& uri, const eckit::Offset& offset, const eckit::Length& length, const Key& remapKey) :
-    FieldLocation(uri, offset, length, remapKey) {
-
-    ASSERT(uri.scheme() == "fdb");
-}
+    FieldLocation(eckit::URI("fdb://" + uri.hostport())),
+    internal_(std::shared_ptr<FieldLocation>(FieldLocationFactory::instance().build(uri.scheme(), uri, offset, length, remapKey))) {}
 
 RemoteFieldLocation::RemoteFieldLocation(eckit::Stream& s) :
-    FieldLocation(s) {
-}
+    FieldLocation(s),
+    internal_(std::shared_ptr<FieldLocation>(eckit::Reanimator<FieldLocation>::reanimate(s))) {}
 
 RemoteFieldLocation::RemoteFieldLocation(const RemoteFieldLocation& rhs) :
-    FieldLocation(rhs.uri_, rhs.offset_, rhs.length_, rhs.remapKey_) {}
+    FieldLocation(rhs.uri_),
+    remoteFDB_(rhs.remoteFDB_),
+    internal_(rhs.internal_) {}
 
 
 std::shared_ptr<FieldLocation> RemoteFieldLocation::make_shared() const {
@@ -77,28 +58,8 @@ std::shared_ptr<FieldLocation> RemoteFieldLocation::make_shared() const {
 }
 
 eckit::DataHandle* RemoteFieldLocation::dataHandle() const {
-    
-    eckit::Log::debug<fdb5::LibFdb5>() << "RemoteFieldLocation::dataHandle for location: ";
-    dump(eckit::Log::debug<fdb5::LibFdb5>());
-    eckit::Log::debug<fdb5::LibFdb5>() << std::endl;
-
-    RemoteStore& store = RemoteStore::get(uri_);
-    
-    const std::string scheme = uri_.query("internalScheme");
-    const std::string hostport = uri_.query("internalHost");
-    eckit::URI remote;
-    if (hostport.empty()) {
-        remote = eckit::URI(scheme, uri_, "",  -1);
-    }
-    else {
-        eckit::net::Endpoint endpoint{hostport};
-        remote = eckit::URI(scheme, uri_, endpoint.host(),  endpoint.port());
-        remote.query("internalHost", "");
-    }
-    remote.query("internalScheme", "");
-    FieldLocation* loc = FieldLocationFactory::instance().build(scheme, remote, offset_, length_, remapKey_);
-
-    return store.dataHandle(*loc);
+    ASSERT(remoteFDB_);
+    return remoteFDB_->dataHandle(*internal_);
 }
 
 void RemoteFieldLocation::visit(FieldLocationVisitor& visitor) const {
@@ -106,31 +67,28 @@ void RemoteFieldLocation::visit(FieldLocationVisitor& visitor) const {
 }
 
 void RemoteFieldLocation::print(std::ostream& out) const {
-    out << "RemoteFieldLocation[uri=" << uri_ << "]";
+    out << "RemoteFieldLocation[uri=" << uri_ << ",internal=" << *internal_ << "]";
 }
 
 void RemoteFieldLocation::encode(eckit::Stream& s) const {
     FieldLocation::encode(s);
-    // s << internalLocationScheme_;
-    // s << internalLocationHostPort_;
-//     std::stringstream ss;
-// //    ss << remoteStore_->config();
-//     s << ss.str();
+    s << *internal_;
+    std::stringstream ss;
+    ss << remoteFDB_->config();
+    s << ss.str();
 }
 
-// void RemoteFieldLocation::dump(std::ostream& out) const {
-//     out << "  uri: " << uri_ << std::endl;
-//     // out << "  internalScheme: " << internalLocationScheme_ << std::endl;
-//     // out << "  internalHost: " << internalLocationHostPort_ << std::endl;
-// }
+void RemoteFieldLocation::dump(std::ostream& out) const {
+    out << "  uri: " << uri_ << std::endl;
+    internal_->dump(out);
+}
 
 static FieldLocationBuilder<RemoteFieldLocation> builder("fdb");
 
 //----------------------------------------------------------------------------------------------------------------------
 
 class FdbURIManager : public eckit::URIManager {
-    bool authority() override { return true; }
-    virtual bool query() override { return true; }
+    virtual bool query() override { return false; }
     virtual bool fragment() override { return false; }
 
     virtual bool exists(const eckit::URI& f) override { return f.path().exists(); }
