@@ -16,14 +16,13 @@
 #include "fdb5/toc/TocCatalogueReader.h"
 #include "fdb5/toc/TocIndex.h"
 #include "fdb5/toc/TocStats.h"
-#include "fdb5/toc/RootManager.h"
 
 namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-TocCatalogueReader::TocCatalogueReader(const Key& dbKey, const fdb5::Config& config) :
-    TocCatalogue(dbKey, config) {
+TocCatalogueReader::TocCatalogueReader(const Key& key, const fdb5::Config& config) :
+    TocCatalogue(key, config) {
     loadIndexesAndRemap();
 }
 
@@ -33,7 +32,7 @@ TocCatalogueReader::TocCatalogueReader(const eckit::URI& uri, const fdb5::Config
 }
 
 TocCatalogueReader::~TocCatalogueReader() {
-    eckit::Log::debug<LibFdb5>() << "Closing DB " << (*this) << std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "Closing DB " << *dynamic_cast<TocCatalogue*>(this) << std::endl;
 }
 
 void TocCatalogueReader::loadIndexesAndRemap() {
@@ -47,22 +46,22 @@ void TocCatalogueReader::loadIndexesAndRemap() {
     }
 }
 
-bool TocCatalogueReader::selectIndex(const Key &idxKey) {
+bool TocCatalogueReader::selectIndex(const Key &key) {
 
-    if(currentIndexKey_ == idxKey) {
+    if(currentIndexKey_ == key) {
         return true;
     }
 
-    currentIndexKey_ = idxKey;
+    currentIndexKey_ = key;
     matching_.clear();
 
     for (auto idx = indexes_.begin(); idx != indexes_.end(); ++idx) {
-        if (idx->first.key() == idxKey) {
+        if (idx->first.key() == key) {
             matching_.push_back(&(*idx));
         }
     }
 
-    eckit::Log::debug<LibFdb5>() << "TocCatalogueReader::selectIndex " << idxKey << ", found "
+    LOG_DEBUG_LIB(LibFdb5) << "TocCatalogueReader::selectIndex " << key << ", found "
                                 << matching_.size() << " matche(s)" << std::endl;
 
     return (matching_.size() != 0);
@@ -104,9 +103,9 @@ void TocCatalogueReader::close() {
     }
 }
 
-bool TocCatalogueReader::retrieve(const InspectionKey& key, Field& field) const {
-    eckit::Log::debug<LibFdb5>() << "Trying to retrieve key " << key << std::endl;
-    eckit::Log::debug<LibFdb5>() << "Scanning indexes " << matching_.size() << std::endl;
+bool TocCatalogueReader::retrieve(const Key& key, Field& field) const {
+    LOG_DEBUG_LIB(LibFdb5) << "Trying to retrieve key " << key << std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "Scanning indexes " << matching_.size() << std::endl;
 
     for (auto m = matching_.begin(); m != matching_.end(); ++m) {
         const Index& idx((*m)->first);
@@ -142,7 +141,7 @@ std::vector<Index> TocCatalogueReader::indexes(bool sorted) const {
     return returnedIndexes;
 }
 
-static CatalogueReaderBuilder<TocCatalogueReader> builder("toc");
+static CatalogueBuilder<TocCatalogueReader> builder("toc.reader");
 
 //----------------------------------------------------------------------------------------------------------------------
 
