@@ -34,11 +34,11 @@ namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-TocStore::TocStore(const Key& key, const Config& config) :
-    Store(), TocCommon(StoreRootManager(config).directory(key).directory_) {}
+TocStore::TocStore(const Schema& schema, const Key& key, const Config& config) :
+    Store(schema), TocCommon(StoreRootManager(config).directory(key).directory_) {}
 
-TocStore::TocStore(const eckit::URI& uri, const Config& config) :
-    Store(), TocCommon(uri.path().dirName()) {}
+TocStore::TocStore(const Schema& schema, const eckit::URI& uri, const Config& config) :
+    Store(schema), TocCommon(uri.path().dirName()) {}
 
 eckit::URI TocStore::uri() const {
     return URI("file", directory_);
@@ -52,8 +52,7 @@ eckit::DataHandle* TocStore::retrieve(Field& field) const {
     return field.dataHandle();
 }
 
-std::unique_ptr<FieldLocation> TocStore::archive(const Key& key, const void *data, eckit::Length length) {
-    
+std::unique_ptr<FieldLocation> TocStore::archive(const Key &key, const void *data, eckit::Length length) {
     dirty_ = true;
 
     eckit::PathName dataPath = getDataPath(key);
@@ -66,7 +65,7 @@ std::unique_ptr<FieldLocation> TocStore::archive(const Key& key, const void *dat
 
     ASSERT(len == length);
 
-    return std::unique_ptr<FieldLocation>(new TocFieldLocation(dataPath, position, length, Key()));
+    return std::unique_ptr<TocFieldLocation>(new TocFieldLocation(dataPath, position, length, Key()));
 }
 
 void TocStore::flush() {
@@ -123,14 +122,14 @@ eckit::DataHandle *TocStore::createFileHandle(const eckit::PathName &path) {
 
     if(stripeLustre()) {
 
-        eckit::Log::debug<LibFdb5>() << "Creating LustreFileHandle<FDBFileHandle> to " << path
+        LOG_DEBUG_LIB(LibFdb5) << "Creating LustreFileHandle<FDBFileHandle> to " << path
                                      << " buffer size " << sizeBuffer
                                      << std::endl;
 
         return new LustreFileHandle<FDBFileHandle>(path, sizeBuffer, stripeDataLustreSettings());
     }
 
-    eckit::Log::debug<LibFdb5>() << "Creating FDBFileHandle to " << path
+    LOG_DEBUG_LIB(LibFdb5) << "Creating FDBFileHandle to " << path
                                  << " with buffer of " << eckit::Bytes(sizeBuffer)
                                  << std::endl;
 
@@ -144,7 +143,7 @@ eckit::DataHandle *TocStore::createAsyncHandle(const eckit::PathName &path) {
 
     if(stripeLustre()) {
 
-        eckit::Log::debug<LibFdb5>() << "Creating LustreFileHandle<AIOHandle> to " << path
+        LOG_DEBUG_LIB(LibFdb5) << "Creating LustreFileHandle<AIOHandle> to " << path
                                      << " with " << nbBuffers
                                      << " buffer each with " << eckit::Bytes(sizeBuffer)
                                      << std::endl;
@@ -268,7 +267,7 @@ void TocStore::remove(const Key& key) const {
     while ((dp = ::readdir(dirp)) != NULL) {
         if (strstr( dp->d_name, ".data")) {
             eckit::PathName dataFile = src_db / dp->d_name;
-            eckit::Log::debug<LibFdb5>() << "Removing " << dataFile << std::endl;
+            LOG_DEBUG_LIB(LibFdb5) << "Removing " << dataFile << std::endl;
             dataFile.unlink(false);
         }
     }
