@@ -16,7 +16,7 @@
 #ifndef fdb5_TocStore_H
 #define fdb5_TocStore_H
 
-#include "fdb5/database/Catalogue.h"
+#include "fdb5/database/DB.h"
 #include "fdb5/database/Index.h"
 #include "fdb5/database/Store.h"
 #include "fdb5/rules/Schema.h"
@@ -33,9 +33,8 @@ class TocStore : public Store, public TocCommon {
 
 public: // methods
 
-    TocStore(const Key& key, const Config& config);
-    TocStore(const Key& key, const Config& config, const eckit::net::Endpoint& controlEndpoint);
-    TocStore(const eckit::URI& uri, const Config& config);
+    TocStore(const Schema& schema, const Key& key, const Config& config);
+    TocStore(const Schema& schema, const eckit::URI& uri, const Config& config);
 
     ~TocStore() override {}
 
@@ -58,7 +57,7 @@ protected: // methods
     bool exists() const override;
 
     eckit::DataHandle* retrieve(Field& field) const override;
-    std::unique_ptr<FieldLocation> archive(const Key& key, const void *data, eckit::Length length) override;
+    std::unique_ptr<FieldLocation> archive(const Key &key, const void *data, eckit::Length length) override;
 
     void remove(const eckit::URI& uri, std::ostream& logAlways, std::ostream& logVerbose, bool doit) const override;
 
